@@ -647,6 +647,12 @@ class Env(BaseEnv):
         self.ctx._validate()
         self.secrets._validate()
 
+        for c in reversed(self.__class__.__mro__):
+            if not issubclass(c, Env):
+                continue
+
+            getattr(c, "post_init")(self)
+
     @classmethod
     def instantiate(cls, stage: Optional[str] = None) -> "Env":
         if not stage:
@@ -659,6 +665,9 @@ class Env(BaseEnv):
         super().init()
         pass
 
+    def post_init(self) -> None:
+        pass
+
     @property
     def id(self) -> str:
         return f"{self.__class__.__module__}:{self.__class__.__name__}"
